##############################################################
# Conduct simulation
# probit w/ clusters
##############################################################

# same-size clusters

#setwd("J:/Justin Esarey/Desktop/Complete Replication File/2015-5-5_binary_simulation_results")
setwd("J:/Dropbox/jesarey_documents/Clustering Project with Andrew/Complete Replication File/2015-5-5_binary_simulation_results")
rm(list=ls())
source(file="clusterIM.glm.R", echo=F)
source(file="clusterwild.glm.R", echo=F)
source(file="clusterBS.glm.R", echo=F)
source(file="2015-5-5_cluster_binary.R", echo=F)
set.seed(387218)
clusterIMtestProbit(obs.per.cluster = rep(40, 3), g.sd = 1, reps=1000)
clusterIMtestProbit(obs.per.cluster = rep(40, 6), g.sd = 1, reps=1000)
clusterIMtestProbit(obs.per.cluster = rep(40, 15), g.sd = 1, reps=1000)
clusterIMtestProbit(obs.per.cluster = rep(40, 21), g.sd = 1, reps=1000)
clusterIMtestProbit(obs.per.cluster = rep(40, 30), g.sd = 1, reps=1000)
clusterIMtestProbit(obs.per.cluster = rep(40, 60), g.sd = 1, reps=1000)
clusterIMtestProbit(obs.per.cluster = rep(40, 75), g.sd = 1, reps=1000)
clusterIMtestProbit(obs.per.cluster = rep(40, 90), g.sd = 1, reps=1000)
clusterIMtestProbit(obs.per.cluster = rep(40, 120), g.sd = 1, reps=1000)

cl.n <- c(3, 6, 15, 21, 30, 60, 75, 90, 120)

vn.result <- matrix(data=NA, nrow=length(cl.n), ncol=3)
cl.result <- matrix(data=NA, nrow=length(cl.n), ncol=3)
mx.result <- matrix(data=NA, nrow=length(cl.n), ncol=3)
im.result <- matrix(data=NA, nrow=length(cl.n), ncol=3)
bs.result.v <- matrix(data=NA, nrow=length(cl.n), ncol=3)
bs.result.c <- matrix(data=NA, nrow=length(cl.n), ncol=3)

im.nonconverge <- c()

for(i in 1:length(cl.n)){
  load(paste("binary-clusters-", cl.n[i],"_unique-1_sd-1.RData", sep=""))  
  
  vn.result[i,] <- colSums(list.out[[1]] < 0.05) / 1000
  cl.result[i,] <- colSums(list.out[[2]] < 0.05) / 1000
  mx.result[i,] <- colSums(list.out[[3]] < 0.05) / 1000
  im.result[i,] <- colSums(list.out[[4]] < 0.05, na.rm = T) / colSums(is.na(list.out[[4]])==F)
  bs.result.v[i,] <- colSums(list.out[[5]] < 0.05) / 1000
  bs.result.c[i,] <- colSums(list.out[[6]] < 0.05) / 1000
  
  # proportion of non-converged results
  im.nonconverge[i] <- colSums(is.na(list.out[[4]]))[1] / 1000
    
}

im.nonconverge
# 0.097 0.181 0.419 0.512 0.653 0.840 0.917 0.948 0.981

# proportion of non-converged results
plot(im.nonconverge ~ cl.n, type = "l", ylim=c(0, 1), xlab = "number of clusters", ylab = "proportion of missing CAT estimates", main = c("Probit GLM w/ CATs", "missing CAT estimates, x coefficient = 0"))

dev.copy2pdf(file="probit-converge.pdf")


plot(vn.result[,1] ~ cl.n, type = "l", ylim = c(0, 0.5), xlab = "number of clusters", ylab = "% of rejected null hypotheses", main = c("Probit False Positive Rates (cluster size = 40)", "Cluster-Correlated Independent Variable"))

lines(bs.result.v[,1] ~ cl.n, lty=1, lwd=3, col="darkgray")
lines(bs.result.c[,1] ~ cl.n, lty=2, lwd=3, col="darkgray")
lines(cl.result[,1] ~ cl.n, lty=2)
lines(im.result[,1] ~ cl.n, lty=4, lwd=2)

legend("right", lty=c(1,2,4,1,2), lwd=c(1,1,2,3,3), col=c(rep("black",3), "darkgray", "darkgray"), legend=c("vanilla SEs", "CRSEs", "CATs", "PCBSTs, vanilla replicates", "PCBSTs, CRSE replicates"))


dev.copy2pdf(file="binary-cluster-corr.pdf")



plot(vn.result[,2] ~ cl.n, type = "l", ylim = c(0, 0.5), xlab = "number of clusters", ylab = "% of rejected null hypotheses", main = c("Probit False Positive Rates (cluster size = 40)", "Cluster-Uncorrelated Independent Variable"))

lines(bs.result.v[,2] ~ cl.n, lty=1, lwd=3, col="darkgray")
lines(bs.result.c[,2] ~ cl.n, lty=2, lwd=3, col="darkgray")
lines(cl.result[,2] ~ cl.n, lty=2)
lines(im.result[,2] ~ cl.n, lty=4, lwd=2)


legend("right", lty=c(1,2,4,1,2), lwd=c(1,1,2,3,3), col=c(rep("black",3), "darkgray", "darkgray"), legend=c("vanilla SEs", "CRSEs", "CATs", "PCBSTs, vanilla replicates", "PCBSTs, CRSE replicates"))

dev.copy2pdf(file="binary-cluster-uncorr.pdf")


##############################################################


# power test, same-size clusters


#setwd("J:/Justin Esarey/Desktop/Complete Replication File/2015-5-5_binary_simulation_results")
setwd("J:/Dropbox/jesarey_documents/Clustering Project with Andrew/Complete Replication File/2015-5-5_binary_simulation_results")
rm(list=ls())
source(file="clusterIM.glm.R", echo=F)
source(file="clusterwild.glm.R", echo=F)
source(file="clusterBS.glm.R", echo=F)
source(file="2015-5-5_cluster_binary_power.R", echo=F)

set.seed(387218)
clusterIMtestProbit(obs.per.cluster = rep(40, 3), g.sd = 1, reps=1000)
clusterIMtestProbit(obs.per.cluster = rep(40, 6), g.sd = 1, reps=1000)
clusterIMtestProbit(obs.per.cluster = rep(40, 15), g.sd = 1, reps=1000)
clusterIMtestProbit(obs.per.cluster = rep(40, 21), g.sd = 1, reps=1000)
clusterIMtestProbit(obs.per.cluster = rep(40, 30), g.sd = 1, reps=1000)
clusterIMtestProbit(obs.per.cluster = rep(40, 60), g.sd = 1, reps=1000)
clusterIMtestProbit(obs.per.cluster = rep(40, 75), g.sd = 1, reps=1000)
clusterIMtestProbit(obs.per.cluster = rep(40, 90), g.sd = 1, reps=1000)
clusterIMtestProbit(obs.per.cluster = rep(40, 120), g.sd = 1, reps=1000)

cl.n <- c(3, 6, 15, 21, 30, 60, 75, 90, 120)

vn.result <- matrix(data=NA, nrow=length(cl.n), ncol=3)
cl.result <- matrix(data=NA, nrow=length(cl.n), ncol=3)
mx.result <- matrix(data=NA, nrow=length(cl.n), ncol=3)
im.result <- matrix(data=NA, nrow=length(cl.n), ncol=3)
bs.result.v <- matrix(data=NA, nrow=length(cl.n), ncol=3)
bs.result.c <- matrix(data=NA, nrow=length(cl.n), ncol=3)


im.nonconverge <- c()

for(i in 1:length(cl.n)){
  load(paste("power-binary-clusters-", cl.n[i],"_unique-1_sd-1.RData", sep=""))
  vn.result[i,] <- colSums(list.out[[1]] < 0.05) / 1000
  cl.result[i,] <- colSums(list.out[[2]] < 0.05) / 1000
  mx.result[i,] <- colSums(list.out[[3]] < 0.05) / 1000
  im.result[i,] <- colSums(list.out[[4]] < 0.05, na.rm = T) / colSums(is.na(list.out[[4]])==F)
  bs.result.v[i,] <- colSums(list.out[[5]] < 0.05) / 1000
  bs.result.c[i,] <- colSums(list.out[[6]] < 0.05) / 1000
  
  # proportion of non-converged results
  im.nonconverge[i] <- colSums(is.na(list.out[[4]]))[1] / 1000
  
  
}

im.nonconverge
# 0.176 0.319 0.661 0.747 0.860 0.986 0.992 0.998 1.000

# proportion of non-converged results
plot(im.nonconverge ~ cl.n, type = "l", ylim=c(0, 1), xlab = "number of clusters", ylab = "proportion of missing CAT estimates", main = c("Probit GLM w/ CATs", "missing CAT estimates, x coefficient = 0.25"))

dev.copy2pdf(file="probit-converge-power.pdf")



plot(vn.result[,1] ~ cl.n, type = "l", ylim = c(0, 1), xlab = "number of clusters", ylab = "% of rejected null hypotheses", main = c("Probit True Positive Rates (cluster size = 40)", "Cluster-Correlated Independent Variable"))

lines(bs.result.v[,1] ~ cl.n, lty=1, lwd=3, col="darkgray")
lines(bs.result.c[,1] ~ cl.n, lty=2, lwd=3, col="darkgray")
lines(cl.result[,1] ~ cl.n, lty=2)
lines(im.result[,1] ~ cl.n, lty=4, lwd=2)

legend("right", lty=c(1,2,4,1,2), lwd=c(1,1,2,3,3), col=c(rep("black",3), "darkgray", "darkgray"), legend=c("vanilla SEs", "CRSEs", "CATs", "PCBSTs, vanilla replicates", "PCBSTs, CRSE replicates"))

dev.copy2pdf(file="binary-power-corr.pdf")



plot(bs.result.v[,2] ~ cl.n, lty=1, lwd=3, col="darkgray", type = "l", ylim = c(0, 1), xlab = "number of clusters", ylab = "% of rejected null hypotheses", main = c("Probit True Positive Rates (cluster size = 40)", "Cluster-Uncorrelated Independent Variable"))

lines(bs.result.c[,2] ~ cl.n, lty=2, lwd=3, col="darkgray")
lines(vn.result[,2] ~ cl.n, lty=1, lwd=1)
lines(cl.result[,2] ~ cl.n, lty=2)
lines(im.result[,2] ~ cl.n, lty=4, lwd=2)

legend("right", lty=c(1,2,4,1,2), lwd=c(1,1,2,3,3), col=c(rep("black",3), "darkgray", "darkgray"), legend=c("vanilla SEs", "CRSEs", "CATs", "PCBSTs, vanilla replicates", "PCBSTs, CRSE replicates"))

dev.copy2pdf(file="binary-power-uncorr.pdf")
