##############################################################
# Conduct simulation
# multinomial logit w/ clusters
##############################################################

# same-size clusters

#setwd("J:/Justin Esarey/Desktop/Complete Replication File/2015-5-6_multinomial_truncated_results")
setwd("J:/Dropbox/jesarey_documents/Clustering Project with Andrew/Complete Replication File/2015-5-6_multinomial_truncated_results")

rm(list=ls())
require(sandwich)
require(lmtest)
source(file="clusterIM.mlogit.R", echo=F)
source(file="clusterBS.mlogit.R", echo=F)
source(file="2015-5-6_cluster_multi.R", echo=F)
set.seed(387218)
clusterIMtestMNL(obs.per.cluster = rep(40, 3), g.sd = 1, reps=1000)
clusterIMtestMNL(obs.per.cluster = rep(40, 6), g.sd = 1, reps=1000)
clusterIMtestMNL(obs.per.cluster = rep(40, 15), g.sd = 1, reps=1000)
clusterIMtestMNL(obs.per.cluster = rep(40, 21), g.sd = 1, reps=1000)
clusterIMtestMNL(obs.per.cluster = rep(40, 30), g.sd = 1, reps=1000)
clusterIMtestMNL(obs.per.cluster = rep(40, 60), g.sd = 1, reps=1000)
clusterIMtestMNL(obs.per.cluster = rep(40, 75), g.sd = 1, reps=1000)
clusterIMtestMNL(obs.per.cluster = rep(40, 90), g.sd = 1, reps=1000)
clusterIMtestMNL(obs.per.cluster = rep(40, 120), g.sd = 1, reps=1000)


cl.n <- c(3, 6, 15, 21, 30, 60, 75, 90, 120)

vn.result <- matrix(data=NA, nrow=length(cl.n), ncol=6)
cl.result <- matrix(data=NA, nrow=length(cl.n), ncol=6)
mx.result <- matrix(data=NA, nrow=length(cl.n), ncol=6)
im.result <- matrix(data=NA, nrow=length(cl.n), ncol=6)
bs.result.v <- matrix(data=NA, nrow=length(cl.n), ncol=6)
bs.result.c <- matrix(data=NA, nrow=length(cl.n), ncol=6)
im.nonconverge <- c()

for(i in 1:length(cl.n)){
  load(paste("multinomial-trunc-clusters-", cl.n[i],"_unique-1_sd-1.RData", sep=""))  
  
  vn.result[i,] <- colSums(list.out[[1]] < 0.05) / 1000
  cl.result[i,] <- colSums(list.out[[2]] < 0.05) / 1000
  mx.result[i,] <- colSums(list.out[[3]] < 0.05) / 1000
  im.result[i,] <- colSums(list.out[[4]] < 0.05, na.rm = T) / colSums(is.na(list.out[[4]])==F)
  bs.result.v[i,] <- colSums(list.out[[5]] < 0.05) / 1000
  bs.result.c[i,] <- colSums(list.out[[6]] < 0.05) / 1000
  
  # proportion of non-converged results
  im.nonconverge[i] <- colSums(is.na(list.out[[4]]))[1] / 1000
  
}

im.nonconverge


plot(vn.result[,1] ~ cl.n, type = "l", ylim = c(0, 0.3), xlab = "number of clusters", ylab = "prop. of rejected null hypotheses", main = c("Multinomial False Positive Rates (cluster size = 40)", "Cluster-Correlated Independent Variable"))

lines(bs.result.v[,1] ~ cl.n, lty=1, lwd=3, col="darkgray")
lines(bs.result.c[,1] ~ cl.n, lty=2, lwd=3, col="darkgray")
lines(cl.result[,1] ~ cl.n, lty=2)
lines(im.result[,1] ~ cl.n, lty=4, lwd=2)

legend("right", lty=c(1,2,4,1,2), lwd=c(1,1,2,3,3), col=c(rep("black",3), "darkgray", "darkgray"), legend=c("vanilla SEs", "CRSEs", "CATs", "PCBSTs, vanilla replicates", "PCBSTs, CRSE replicates"))

dev.copy2pdf(file="multinomial-trunc-cluster-t-corr.pdf")





plot(vn.result[,3] ~ cl.n, type = "l", ylim = c(0, 0.3), xlab = "number of clusters", ylab = "prop. of rejected null hypotheses", main = c("Multinomial False Positive Rates (cluster size = 40)", "Cluster-Uncorrelated Independent Variable"))

lines(bs.result.v[,3] ~ cl.n, lty=1, lwd=3, col="darkgray")
lines(bs.result.c[,3] ~ cl.n, lty=2, lwd=3, col="darkgray")
lines(cl.result[,3] ~ cl.n, lty=2)
lines(im.result[,3] ~ cl.n, lty=4, lwd=2)

legend("right", lty=c(1,2,4,1,2), lwd=c(1,1,2,3,3), col=c(rep("black",3), "darkgray", "darkgray"), legend=c("vanilla SEs", "CRSEs", "CATs", "PCBSTs, vanilla replicates", "PCBSTs, CRSE replicates"))

dev.copy2pdf(file="multinomial-trunc-cluster-t-uncorr.pdf")






















##############################################################
# Conduct power simulation
# multinomial logit w/ clusters
##############################################################

# same-size clusters

#setwd("J:/Justin Esarey/Desktop/Complete Replication File/2015-5-6_multinomial_truncated_results")
setwd("J:/Dropbox/jesarey_documents/Clustering Project with Andrew/Complete Replication File/2015-5-6_multinomial_truncated_results")
rm(list=ls())
require(sandwich)
require(lmtest)
source(file="clusterIM.mlogit.R", echo=F)
source(file="clusterBS.mlogit.R", echo=F)
source(file="2015-5-6_cluster_multi_power.R", echo=F)
set.seed(387218)
clusterIMtestMNL(obs.per.cluster = rep(40, 3), g.sd = 1, reps=1000)
clusterIMtestMNL(obs.per.cluster = rep(40, 6), g.sd = 1, reps=1000)
clusterIMtestMNL(obs.per.cluster = rep(40, 15), g.sd = 1, reps=1000)
clusterIMtestMNL(obs.per.cluster = rep(40, 21), g.sd = 1, reps=1000)
clusterIMtestMNL(obs.per.cluster = rep(40, 30), g.sd = 1, reps=1000)
clusterIMtestMNL(obs.per.cluster = rep(40, 60), g.sd = 1, reps=1000)
clusterIMtestMNL(obs.per.cluster = rep(40, 75), g.sd = 1, reps=1000)
clusterIMtestMNL(obs.per.cluster = rep(40, 90), g.sd = 1, reps=1000)
clusterIMtestMNL(obs.per.cluster = rep(40, 120), g.sd = 1, reps=1000)


cl.n <- c(3, 6, 15, 21, 30, 60, 75, 90, 120)

vn.result <- matrix(data=NA, nrow=length(cl.n), ncol=6)
cl.result <- matrix(data=NA, nrow=length(cl.n), ncol=6)
mx.result <- matrix(data=NA, nrow=length(cl.n), ncol=6)
im.result <- matrix(data=NA, nrow=length(cl.n), ncol=6)
bs.result.v <- matrix(data=NA, nrow=length(cl.n), ncol=6)
bs.result.c <- matrix(data=NA, nrow=length(cl.n), ncol=6)
im.nonconverge <- c()

for(i in 1:length(cl.n)){
  load(paste("multinomial-trunc-power-clusters-", cl.n[i],"_unique-1_sd-1.RData", sep=""))  
  
  vn.result[i,] <- colSums(list.out[[1]] < 0.05) / 1000
  cl.result[i,] <- colSums(list.out[[2]] < 0.05) / 1000
  mx.result[i,] <- colSums(list.out[[3]] < 0.05) / 1000
  im.result[i,] <- colSums(list.out[[4]] < 0.05, na.rm = T) / colSums(is.na(list.out[[4]])==F)
  bs.result.v[i,] <- colSums(list.out[[5]] < 0.05) / 1000
  bs.result.c[i,] <- colSums(list.out[[6]] < 0.05) / 1000
  
  # proportion of non-converged results
  im.nonconverge[i] <- colSums(is.na(list.out[[4]]))[1] / 1000
  
}

im.nonconverge


plot(vn.result[,1] ~ cl.n, type = "l", ylim = c(0, 1), xlab = "number of clusters", ylab = "prop. of rejected null hypotheses", main = c("Multinomial True Positive Rates (cluster size = 40)", "Cluster-Correlated Independent Variable"))

lines(bs.result.v[,1] ~ cl.n, lty=1, lwd=3, col="darkgray")
lines(bs.result.c[,1] ~ cl.n, lty=2, lwd=3, col="darkgray")
lines(cl.result[,1] ~ cl.n, lty=2)
lines(im.result[,1] ~ cl.n, lty=4, lwd=2)

legend("bottomright", lty=c(1,2,4,1,2), lwd=c(1,1,2,3,3), col=c(rep("black",3), "darkgray", "darkgray"), legend=c("vanilla SEs", "CRSEs", "CATs", "PCBSTs, vanilla replicates", "PCBSTs, CRSE replicates"))

dev.copy2pdf(file="multinomial-trunc-power-cluster-t-corr.pdf")





plot(vn.result[,3] ~ cl.n, type = "l", ylim = c(0, 1), xlab = "number of clusters", ylab = "prop. of rejected null hypotheses", main = c("Multinomial True Positive Rates (cluster size = 40)", "Cluster-Uncorrelated Independent Variable"))

lines(bs.result.v[,3] ~ cl.n, lty=1, lwd=3, col="darkgray")
lines(bs.result.c[,3] ~ cl.n, lty=2, lwd=3, col="darkgray")
lines(cl.result[,3] ~ cl.n, lty=2)
lines(im.result[,3] ~ cl.n, lty=4, lwd=2)

legend("bottomright", lty=c(1,2,4,1,2), lwd=c(1,1,2,3,3), col=c(rep("black",3), "darkgray", "darkgray"), legend=c("vanilla SEs", "CRSEs", "CATs", "PCBSTs, vanilla replicates", "PCBSTs, CRSE replicates"))


dev.copy2pdf(file="multinomial-trunc-power-cluster-t-uncorr.pdf")
