####################################################################
# Monte Carlo Test
# Vanilla SE vs. Cluster SE vs. Cluster-Adjusted SE
# 
# Linear Model
####################################################################

clusterIMtestLinear<-function(obs.per.cluster, g.sd, reps=1000){
  
  require(lme4)
  
  total.obs <- sum(obs.per.cluster)
  n.clusters <- length(obs.per.cluster)

  vn.beta <- matrix(data=NA, nrow=reps, ncol=3)
  re.beta <- matrix(data=NA, nrow=reps, ncol=3)
  
  vn.res <- matrix(data=NA, nrow=reps, ncol=3)
  cl.res <- matrix(data=NA, nrow=reps, ncol=3)
  mx.res <- matrix(data=NA, nrow=reps, ncol=3)
  im.res <- matrix(data=NA, nrow=reps, ncol=3)
  wd.res <- matrix(data=NA, nrow=reps, ncol=3)
  bs.res.v <- matrix(data=NA, nrow=reps, ncol=3)
  bs.res.c <- matrix(data=NA, nrow=reps, ncol=3)
  re.res <- matrix(data=NA, nrow=reps, ncol=3)
  
  # load in a function to create clustered standard errors
  # by Mahmood Ara: http://thetarzan.wordpress.com/2011/06/11/clustered-standard-errors-in-r/
  cl   <- function(dat, fm, cluster){
    require(sandwich, quietly = TRUE)
    require(lmtest, quietly = TRUE)
    M <- length(unique(cluster))
    N <- length(cluster)
    K <- fm$rank
    dfc <- (M/(M-1))
    uj  <- apply(estfun(fm),2, function(x) tapply(x, cluster, sum));
    vcovCL <- dfc*sandwich(fm, meat=crossprod(uj)/N)
    coeftest(fm, vcovCL, df=(M-1)) }

  pb <- txtProgressBar(min=0, max=reps, initial=0, style=3)
  for(i in 1:reps){

    setTxtProgressBar(pb, value=i)
    
    g <- rep(1:n.clusters, times=obs.per.cluster)
    g.ef <- rnorm(n.clusters, mean = 0, sd = g.sd)
    g.ob <- g.ef[g]
    
    x.mean <- runif(n.clusters, min = 1, max = 5)
    x <- rnorm( total.obs, mean = x.mean[g], sd = 1 )
    z <- rnorm( total.obs, mean = 0, sd = 1)
    w <- rnorm( total.obs, mean = 0, sd = 1)
    
    y <- w + g.ob + rnorm(total.obs, mean=0, sd=1)
    
    dat<-data.frame(y,x,z,w,g)
    
    mod<-glm(y~x+z+w, family=gaussian(link="identity"), data=dat)
    vn.beta[i,] <- coefficients(mod)[2:4]
    
    vn.res[i,] <- summary(mod)$coefficients[2:4, 4]
    cl.res[i,] <- cl(dat, mod, g)[2:4, 4]
    mx.res[i,] <- apply(rbind(vn.res[i,], cl.res[i,]), MARGIN=2, FUN=max)
    im.res[i,] <- tryCatch(cluster.im.glm(mod, dat, ~g, report = F)$p.values[2:4], error = function(e){return(NA)})
    wd.res[i,] <- cluster.wild.glm(mod, dat, ~g, report = F, prog.bar = F, boot.reps=100)$p.values[2:4]
    bs.res.v[i,] <- cluster.bs.glm(mod, dat, ~g, report = F, boot.reps=100, prog.bar=F, cluster.se = FALSE)$p.values[2:4]
    bs.res.c[i,] <- cluster.bs.glm(mod, dat, ~g, report = F, boot.reps=100, prog.bar=F, cluster.se = TRUE)$p.values[2:4]
    
    temp <- tryCatch( lmer(y~x+z+w+(1|g)), error = function(e){return(NULL)}, warning = function(w){return(NULL)} )
    if( is.null(temp) == F ){
      re.beta[i,] <- unlist(coefficients(temp)$g[1,2:4])
      re.res[i,] <- ( 2*(1 - pnorm( abs( coef(summary(temp))[,"t value"] ) )) )[2:4]
    }else{
      re.beta[i,] <- NA
      re.res[i,] <- NA
    }
    
  }
  close(pb)

  save.name <- paste("linear-clusters-", as.character(n.clusters), "_unique-", as.character(length(unique(obs.per.cluster))), "_sd-", g.sd, ".RData", sep="")
  list.out <- list(vn.beta=vn.beta, re.beta=re.beta, vn.res=vn.res, cl.res=cl.res, mx.res=mx.res, im.res=im.res, wd.res=wd.res, bs.res.v=bs.res.v, bs.res.c=bs.res.c, re.res=re.res)
  save(list.out, file=save.name)
  

}
