####################################################################
# Monte Carlo Test
# Vanilla SE vs. Cluster SE vs. Cluster-Adjusted SE
# 
# Linear Model
####################################################################

clusterIMtestLinear<-function(obs.per.cluster, g.sd, reps=1000){
  
  require(lme4)
  require(plm)
  
  total.obs <- sum(obs.per.cluster)
  n.clusters <- length(obs.per.cluster)

  vn.beta <- matrix(data=NA, nrow=reps, ncol=3)
  re.beta <- matrix(data=NA, nrow=reps, ncol=3)
  
  vn.res <- matrix(data=NA, nrow=reps, ncol=3)
  cl.res <- matrix(data=NA, nrow=reps, ncol=3)
  mx.res <- matrix(data=NA, nrow=reps, ncol=3)
  im.res <- matrix(data=NA, nrow=reps, ncol=3)
  wd.res <- matrix(data=NA, nrow=reps, ncol=3)
  bs.res.v <- matrix(data=NA, nrow=reps, ncol=3)
  bs.res.c <- matrix(data=NA, nrow=reps, ncol=3)
  re.res <- matrix(data=NA, nrow=reps, ncol=3)
  
  require(sandwich)
  require(lmtest)

  pb <- txtProgressBar(min=0, max=reps, initial=0, style=3)
  for(i in 1:reps){

    setTxtProgressBar(pb, value=i)
    
    g <- rep(1:n.clusters, times=obs.per.cluster)
    g.ef <- rnorm(n.clusters, mean = 0, sd = g.sd)
    g.ob <- g.ef[g]
    
    x.mean <- 1.5*g.ef
#   x <- rnorm( total.obs, mean = x.mean[g], sd = 1 )
    z <- rnorm( total.obs, mean = 0, sd = 1)
    w <- rnorm( total.obs, mean = 0, sd = 1)
    
    u <- c()
    x <- c()
    for(j in 1:n.clusters){
      u.t <- rnorm(1, mean=0, sd=1)
      x.t <- rnorm(1, mean=0, sd=1)
      for(k in 2:obs.per.cluster[j]){
        u.t[k] <- 0.9*u.t[k-1] + rnorm(1, mean=0, sd=0.1)
        x.t[k] <- 0.9*x.t[k-1] + rnorm(1, 0, 0.1)
      }
      u <- c(u, u.t)
      x <- c(x, (x.t + x.mean[j]) )
    }
    
    y <- w + 0.5*x + 0.5*z + g.ob + u
    
    dat<-data.frame(y,x,z,w,g)
    dat.p<-pdata.frame(dat, index="g")
    
    mod.g<-glm(y~x+z+w, family=gaussian(link="identity"), data=dat)
    mod<-plm(y~x+z+w, dat.p, effect="individual", model="within")
    vn.beta[i,] <- coefficients(mod)[1:3]
    
    vn.res[i,] <- summary(mod)$coefficients[1:3, 4]
    cl.res[i,] <- coeftest(mod, (n.clusters/(n.clusters-1))*vcovHC(mod, cluster="group"), df=(n.clusters-1))[1:3, 4]
    mx.res[i,] <- apply(rbind(vn.res[i,], cl.res[i,]), MARGIN=2, FUN=max)
    im.res[i,] <- tryCatch(cluster.im.glm(mod.g, dat, ~g, report = F)$p.values[2:4], error = function(e){return(NA)})
    wd.res[i,] <- cluster.wild.plm(mod, dat.p, "group", report = F, prog.bar = F, boot.reps=100)$p.values[1:3]
    bs.res.v[i,] <- cluster.bs.plm(mod, dat.p, "group", report = F, boot.reps=100, prog.bar=F, cluster.se = FALSE)$p.values[1:3]
    bs.res.c[i,] <- cluster.bs.plm(mod, dat.p, "group", report = F, boot.reps=100, prog.bar=F, cluster.se = TRUE)$p.values[1:3]
    
    temp <- tryCatch( lmer(y~x+z+w+(1|g)), error = function(e){return(NULL)}, warning = function(w){return(NULL)} )
    if( is.null(temp) == F ){
      re.beta[i,] <- unlist(coefficients(temp)$g[1,2:4])
      re.res[i,] <- ( 2*(1 - pnorm( abs( coef(summary(temp))[,"t value"] ) )) )[2:4]
    }else{
      re.beta[i,] <- NA
      re.res[i,] <- NA
    }
    
  }
  close(pb)

  save.name <- paste("power-linear-fe-acor-clusters-", as.character(n.clusters), "_unique-", as.character(length(unique(obs.per.cluster))), "_sd-", g.sd, ".RData", sep="")
  list.out <- list(vn.beta=vn.beta, re.beta=re.beta, vn.res=vn.res, cl.res=cl.res, mx.res=mx.res, im.res=im.res, wd.res=wd.res, bs.res.v=bs.res.v, bs.res.c=bs.res.c, re.res=re.res)
  save(list.out, file=save.name)
  

}
