# example one: cluster coefficient distribution
# mean beta = 5, sigma = 1

rm(list=ls())

# true mean value of a coefficient across clusters
B <- 5

# hypothetical values of a coefficient
B.plot <- seq(from=0, to=10, by=0.1)
# structured data set (answers vary by x)
x<-seq(from=0.01, to=1, by=0.01)
# probability of missingness storage vector
miss.pr <- c()

# calculate pr(miss) for every value of B.plot
for(i in 1:length(B.plot)){
  
  # probability of y = 1 in the data set, note setting of variance
  pr.y <- pnorm(B.plot[i] * x, sd=1)
  miss.pr[i] <- prod(pr.y) + prod(1-pr.y)
  
}
# compute missingness-adjusted density when mean B = B
conv.norm <- (1-miss.pr) * dnorm(B.plot, mean=B, sd=1)
conv.norm <- conv.norm / (sum(conv.norm)*0.1)


# plot the true and adjusted densities
setEPS()
postscript("small-distort-density.eps", width=6, height=6)

plot(conv.norm~B.plot, lty=2, lwd=2, type="l", ylim=c(0,0.5), xlab="coefficient value", ylab="density")
true <- dnorm(B.plot, mean=B, sd=1) 
lines(true~B.plot, lty=2)
legend("topright", legend=c("true cluster coefficient density", "density of coefficient in non-dropped clusters"), lty=c(1,2), lwd=c(1,2))

dev.off()

setEPS()
postscript("small-distort-missingness.eps", width=6, height=6)

# plot the probability of missingness against the true density
plot(miss.pr ~ B.plot, type="l", lty=2, lwd=2, ylim=c(0, 0.016), ylab="probability of no variation / rescaled density", xlab="coefficient value")
conv.norm.plot = conv.norm*(max(miss.pr)/max(conv.norm))
lines(lines(conv.norm.plot~B.plot))
legend("topright", legend=c("true cluster coefficient density", "probability of no variation in DV"), lty=c(1,2), lwd=c(1,2))

dev.off()







# example one: cluster coefficient distribution
# mean beta = 25, sigma = 12

rm(list=ls())

# true mean value of a coefficient across clusters
B <- 25

# hypothetical values of a coefficient
B.plot <- seq(from=-10, to=60, by=0.1)
# structured data set (answers vary by x)
x<-seq(from=0.01, to=1, by=0.01)
# probability of missingness storage vector
miss.pr <- c()

# calculate pr(miss) for every value of B.plot
for(i in 1:length(B.plot)){
  
  # probability of y = 1 in the data set, note setting of variance
  pr.y <- pnorm(B.plot[i] * x, sd=1)
  miss.pr[i] <- prod(pr.y) + prod(1-pr.y)
  
}
# compute missingness-adjusted density when mean B = B
conv.norm <- (1-miss.pr) * dnorm(B.plot, mean=B, sd=12)
conv.norm <- conv.norm / (sum(conv.norm)*0.1)

# plot the true and adjusted densities
setEPS()
postscript("large-distort-density.eps", width=6, height=6)

plot(conv.norm~B.plot, lty=2, lwd=2, type="l", ylim=c(0,0.0425), xlab="coefficient value", ylab="density")
true <- dnorm(B.plot, mean=B, sd=12) 
lines(true~B.plot, lty=2)
legend("topright", legend=c("true cluster coefficient density", "density of coefficient in non-dropped clusters"), lty=c(1,2), lwd=c(1,2))

dev.off()

setEPS()
postscript("large-distort-missingness.eps", width=6, height=6)

# plot the probability of missingness against the true density
plot(miss.pr ~ B.plot, type="l", lty=2, lwd=2, ylim=c(0, 0.71), ylab="probability of no variation / rescaled density", xlab="coefficient value")
conv.norm.plot = conv.norm*(max(miss.pr)/max(conv.norm))
lines(lines(conv.norm.plot~B.plot))
legend("topright", legend=c("true cluster coefficient density", "probability of no variation in DV"), lty=c(1,2), lwd=c(1,2))

dev.off()
