* Replication Code for 
* Consumer Demand for the Fair Trade Label: Evidence from a Multi-Store Field Experiment
* Jens Hainmueller -- Stanford University
* Michael J. Hiscox -- Harvard University
* Sandra Sequeira -- London School of Economics 

* reanalysis by Justin Esarey and Andrew Menger with new clustering techniques
* original do file saved as repcode.do

version 13.2
clear
set more off

log using hainmueller-rep.log, replace

** Table 5: Main Results: Label and Price Experiment
use "repTable4and5.dta", clear

* compute delta_ij
egen sharesum = sum(salesshare) , by(store periodfw)
gen  outshare=1-sharesum
gen  delta = log(salesshare)-log(outshare)
drop outshare sharesum

* product store fixed effects
egen storeprod=group(itemno store)

** code coffee indicators for Label experiment
* FR Regular and Coffee Blend
gen     FRCB = 0
replace FRCB = 1 if FTweek==1 & (prod=="COF FRENCH ROAST OG BULK" | prod=="COFFEE BLEND BULK")

* FR Regular
gen     xxFR = 0
replace xxFR = 1 if FTweek==1 & prod=="COF FRENCH ROAST OG BULK"

* Coffee Blend
gen     xxCB = 0
replace xxCB = 1 if FTweek==1 & prod=="COFFEE BLEND BULK"

* Breakfast Blend
gen     xxBB = 0
replace xxBB = 1 if FTweek==1 & prod=="COF BREAKFAST BLEND OG BULK"

* Colombian Supremo
gen     xxCS = 0
replace xxCS = 1 if FTweek==1 & prod=="COF COLOMBIAN SUPREMO BULK"

* FR Extra Dark
gen     xxFRD = 0
replace xxFRD = 1 if FTweek==1 & prod=="COF FRENCH EXTRA DARK BULK"

* Regional Blend
gen     xxRB = 0
replace xxRB = 1 if FTweek==1 & prod=="COF REGIONAL BLEND OG BULK"

* Mexican
gen     xxMEX = 0
replace xxMEX = 1 if FTweek==1 & prod=="COF MEXICAN OG BULK"

** Results

* model 1: Regular and Coffee Blend (Table 3, column 1)
xtreg delta salesp FRCB i.periodfw, i(storeprod) fe level(95) cl(store) , if exp1period==1
mat g = e(b)



keep if exp1period==1
tab periodfw, gen(perdum)
tab itemno, gen(itemdum)

* cluster bootstrap w/ Andrew's program
clusterbs regress delta salesp FRCB perdum2-perdum8, cluster(store) fe(inside) festruc(itemno) reps(5000) seed(123456)

* Ibragimov-Muller SEs (Table 3, Column 3)
clustse reg delta salesp FRCB perdum2-perdum8 itemdum2-itemdum7, cluster(store) force(no)

* Ibragimov-Muller SEs
* no item dummies, no force option
clustse reg delta salesp FRCB perdum2-perdum8, cluster(store)
saveold hain-dat-r.dta, replace

* cluster bootstrap the pivotal statistic using clustered SEs
* (Table 3, column 2)
program myxtreg, rclass
egen tempstoreprod=group(itemno tempstore)
xtreg delta salesp FRCB i.periodfw, i(tempstoreprod) fe cluster(tempstore)
drop tempstoreprod
end

bootstrap t_piv = ((_b[FRCB] - g[1,2])/_se[FRCB]), r(1000) seed(123456) cluster(store) idcluster(tempstore) saving(hain-reps, replace): myxtreg


label variable FRCB "fair trade label (1 = present, 0 = absent)"
label variable delta "delta"

*twoway (scatter delta FRCB) (lfit delta FRCB)
twoway (scatter delta FRCB) (lfit delta FRCB), by(store) xlabel(0 1) ytitle("delta")
graph export hainmueller-plot.pdf, replace

sort store
statsby _b, by(store) clear: reg delta FRCB
scatter _b_FRCB store, ytitle("store-level coefficient on free trade label") xtitle("store number")
graph export hainmueller-bystore.pdf, replace

* this is where cluster bootstrapping results are calculated
use hain-reps, replace

gen abs_t_piv = abs(t_piv)
sum abs_t_piv, detail

gen sig = abs_t_piv > 2.91
sum sig
* p-value is 0.009.

* 95% CI
display .1026375 + 2.176954*.0352325
display .1026375 - 2.176954*.0352325

log close